@@ -5,11 +5,9 @@ use Bubblegum::Role 'requires', 'with';
 
 with 'Bubblegum::Object::Role::Defined';
 
-our $VERSION = '0.29'; # VERSION
+our $VERSION = '0.30'; # VERSION
 
 requires 'print';
-requires 'printf';
 requires 'say';
-requires 'sayf';
 
 1;
